<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>AIAssistantWidget</name>
    <message>
        <source>Explain</source>
        <translation>Пояснити</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Перекласти</translation>
    </message>
    <message>
        <source>Ask AI</source>
        <translation>Запитати AI</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation>Підсумок</translation>
    </message>
</context>
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Натисніть піктограму у лотку
або натисніть гарячі клавіші ще раз, щоб зупинити запис</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Не обертайте екран під час запису</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Знімок</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Записування</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Закрити (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Скопіювати до буфера обміну (Enter)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Захоплення екрана</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Не вдалося зберегти. Будь ласка, збережіть дані до вашого домашнього каталогу.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Перегляд</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Знімок створено</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>вибір_області</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Збережено до %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ігнорувати</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Буфер обміну</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Зберігаємо записаний з екрана файл. Будь ласка, зачекайте…</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Оскільки під час процедури було вимкнено ефекти вікон, запис довелося припинити</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Знімок</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Знімок із гортанням</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Пришпилити знімки</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>Засіб запису екрана Deepin</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Відкрити теку</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Знімок завершено і скопійовано до буфера обміну</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вийти</translation>
    </message>
</context>
<context>
    <name>PinSaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Кожне запитування</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Вказане місце</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Встановити шлях для збереження</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Змінити шлях для збереження</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Стільниця</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Зображення</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Пришпилити знімки</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Знімок</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Запис</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Знімок</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Записування</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Запис закінчено</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Збережено до %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Записати</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Відкрити теку</translation>
    </message>
</context>
<context>
    <name>SaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Кожне запитування</translation>
    </message>
    <message>
        <source>Specified location</source>
        <translation>Вказане місце</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Виберіть місце для збереження</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Оновити місце для збереження</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Стільниця</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Зображення</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Захоплення зображення з екрана розпочнеться за %1 секунд</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Довідка.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Не вдалося зробити неперервний знімок.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Досягнуто кінця області гортання</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Досягнуто максимальної довжини</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>скоригувати область захоплення</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Прокручуйте коліщатко миші або клацніть для створення знімка із гортанням</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Уповільнити швидкість гортання</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Некоректна ділянка, клацніть, щоб</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Тут можна ввести текст</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Пуск/Знімок</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Вийти/Зберегти</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Коригування розміру</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Початкові зауваження</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Знімок вікна</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Затриманий знімок екрана</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Повний знімок екрана</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Прямокутник</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Еліпс</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Пряма</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Олівець</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Вернути</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Збільшити висоту згори</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Збільшити висоту внизу</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Збільшити ширину ліворуч</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Збільшити ширину праворуч</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Зменшити висоту згори</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Зменшити висоту внизу</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Зменшити ширину ліворуч</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Зменшити ширину праворуч</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Довідка</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Показати клавіатурні скорочення</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Натискання клавіш</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Вебкамера</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Розпочати запис</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Почати/Запис</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Миша</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Інструменти</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Видобути текст</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Знімок із гортанням</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Пришпилити знімки</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Почати розпізнавання</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Почати знімок із гортанням</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Стрілка</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Знімок</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Запис</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Прямокутник
Натисніть і утримуйте клавішу Shift, щоб намалювати квадрат</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Еліпс
Натисніть і утримуйте клавішу Shift, щоб намалювати коло</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Пензель
Натисніть і утримуйте клавішу Shift, щоб намалювати пряму лінію</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Скоригувати потужність розмивання (крутіть коліщатко для зміни)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Скоригувати розмір пензля (крутіть коліщатко для зміни)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Скоригувати розмір символів (крутіть коліщатко для зміни)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Показати натискання клавіш (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Приховати натискання клавіш (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Показати натискання клавіш (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Увімкнути камеру (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Вимкнути камеру (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Знімок</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Параметри (F3)</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>Частота кадрів</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 кд/с</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 кд/с</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 кд/с</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 кд/с</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 кд/с</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Мікрофон</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Загальносистемний звук</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Показати вказівник</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Показати клацання</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Місце збереження</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Стільниця</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Пряма (L)
Натисніть і утримуйте клавішу Shift, щоб намалювати вертикальну або горизонтальну пряму</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Стрілка (X)
Натисніть і утримуйте клавішу Shift, щоб намалювати вертикальну або горизонтальну стрілку</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Олівець (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Розмивання (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Текст (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Знімок з гортанням (Alt+I）</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Видобути текст (Alt+O）</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Пришпилити знімки (Alt+P）</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Скасувати (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Записати</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Змінити шлях для збереження</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Ефекти рамки</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Тінь</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Рамка</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Пристрій</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Видобути текст</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Геометричні інструменти (R)
Утримуйте Shift для малювання квадратів або кіл.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Зберегти локально</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Зберегти до %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Вказане місце</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Оновити місце для збереження</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Виберіть місце для збереження</translation>
    </message>
    <message>
        <source>AI Screenshot (A)</source>
        <translation>AI знімок (A)</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>Зберегти на стільницю</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>Зберегти в зображення</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Закрити (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Скопіювати до буфера обміну (Enter)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>OK Enter</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Скоригуйте ділянку запису до %1*%2, щоб отримати краще відео</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Зараз підтримки запису з екрана не передбачено</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вийти</translation>
    </message>
</context>
</TS>
